package com.cirs.biz.service;

import java.util.List;
import com.cirs.biz.domain.TElectronComponent;

/**
 * 元器件Service接口
 * 
 * @author allen
 * @date 2023-11-03
 */
public interface ITElectronComponentService 
{
    /**
     * 查询元器件
     * 
     * @param id 元器件主键
     * @return 元器件
     */
    public TElectronComponent selectTElectronComponentById(Long id);

    /**
     * 查询元器件列表
     * 
     * @param tElectronComponent 元器件
     * @return 元器件集合
     */
    public List<TElectronComponent> selectTElectronComponentList(TElectronComponent tElectronComponent);

    /**
     * 新增元器件
     * 
     * @param tElectronComponent 元器件
     * @return 结果
     */
    public int insertTElectronComponent(TElectronComponent tElectronComponent);

    /**
     * 修改元器件
     * 
     * @param tElectronComponent 元器件
     * @return 结果
     */
    public int updateTElectronComponent(TElectronComponent tElectronComponent);

    /**
     * 批量删除元器件
     * 
     * @param ids 需要删除的元器件主键集合
     * @return 结果
     */
    public int deleteTElectronComponentByIds(Long[] ids);

    /**
     * 删除元器件信息
     * 
     * @param id 元器件主键
     * @return 结果
     */
    public int deleteTElectronComponentById(Long id);

    public List<TElectronComponent> getAll();

    public String importComponent(List<TElectronComponent> componentList, boolean updateSupport, String operName);

    public String getDetailById(Long id);
}
